@@ -25,7 +25,19 @@ NO_DEFAULT = object()
 class Task(object):
     """
     Core object representing an executable task & its argument specification.
+
+    For the most part, this object is a clearinghouse for all of the data that
+    may be supplied to the `@task <invoke.tasks.task>` decorator, such as
+    ``name``, ``aliases``, ``positional`` etc, which appear as attributes.
+
+    In addition, instantiation copies some introspection/documentation friendly
+    metadata off of the supplied ``body`` object, such as ``__doc__``,
+    ``__name__`` and ``__module__``, allowing it to "appear as" ``body`` for
+    most intents and purposes.
+
+    .. versionadded:: 1.0
     """
+
     # TODO: store these kwarg defaults central, refer to those values both here
     # and in @task.
     # TODO: allow central per-session / per-taskmodule control over some of
@@ -33,7 +45,8 @@ class Task(object):
     # NOTE: we shadow __builtins__.help here on purpose - obfuscating to avoid
     # it feels bad, given the builtin will never actually be in play anywhere
     # except a debug shell whose frame is exactly inside this class.
-    def __init__(self,
+    def __init__(
+        self,
         body,
         name=None,
         aliases=(),
@@ -50,9 +63,11 @@ class Task(object):
     ):
         # Real callable
         self.body = body
-        # Must copy doc/name here because Sphinx is stupid about properties.
-        self.__doc__ = getattr(body, '__doc__', '')
-        self.__name__ = getattr(body, '__name__', '')
+        # Copy a bunch of special properties from the body for the benefit of
+        # Sphinx autodoc or other introspectors.
+        self.__doc__ = getattr(body, "__doc__", "")
+        self.__name__ = getattr(body, "__name__", "")
+        self.__module__ = getattr(body, "__module__", "")
         # Default name, alternate names, and whether it should act as the
         # default for its parent collection
         self._name = name
@@ -79,7 +94,7 @@ class Task(object):
     def __repr__(self):
         aliases = ""
         if self.aliases:
-            aliases = " ({})".format(', '.join(self.aliases))
+            aliases = " ({})".format(", ".join(self.aliases))
         return "<Task {!r}{}>".format(self.name, aliases)
 
     def __eq__(self, other):
@@ -92,10 +107,9 @@ class Task(object):
             return True
         else:
             try:
-                return (
-                    six.get_function_code(self.body) ==
-                    six.get_function_code(other.body)
-                )
+                return six.get_function_code(
+                    self.body
+                ) == six.get_function_code(other.body)
             except AttributeError:
                 return False
 
@@ -130,6 +144,8 @@ class Task(object):
         * Second item is dict mapping arg names to default values or
           `.NO_DEFAULT` (an 'empty' value distinct from None, since None
           is a valid value on its own).
+
+        .. versionadded:: 1.0
         """
         # Handle callable-but-not-function objects
         # TODO: __call__ exhibits the 'self' arg; do we manually nix 1st result
@@ -154,7 +170,7 @@ class Task(object):
         # value will be automatically considered positional.
         if positional is None:
             positional = []
-            for name in args: # Go in defined order, not dict "order"
+            for name in args:  # Go in defined order, not dict "order"
                 default = spec_dict[name]
                 if default is NO_DEFAULT:
                     positional.append(name)
@@ -163,23 +179,23 @@ class Task(object):
     def arg_opts(self, name, default, taken_names):
         opts = {}
         # Whether it's positional or not
-        opts['positional'] = name in self.positional
+        opts["positional"] = name in self.positional
         # Whether it is a value-optional flag
-        opts['optional'] = name in self.optional
+        opts["optional"] = name in self.optional
         # Whether it should be of an iterable (list) kind
         if name in self.iterable:
-            opts['kind'] = list
+            opts["kind"] = list
             # If user gave a non-None default, hopefully they know better
             # than us what they want here (and hopefully it offers the list
             # protocol...) - otherwise supply useful default
-            opts['default'] = default if default is not None else []
+            opts["default"] = default if default is not None else []
         # Whether it should increment its value or not
         if name in self.incrementable:
-            opts['incrementable'] = True
+            opts["incrementable"] = True
         # Argument name(s) (replace w/ dashed version if underscores present,
         # and move the underscored version to be the attr_name instead.)
-        if '_' in name:
-            opts['attr_name'] = name
+        if "_" in name:
+            opts["attr_name"] = name
             name = translate_underscores(name)
         names = [name]
         if self.auto_shortflags:
@@ -188,7 +204,7 @@ class Task(object):
                 if not (char == name or char in taken_names):
                     names.append(char)
                     break
-        opts['names'] = names
+        opts["names"] = names
         # Handle default value & kind if possible
         if default not in (None, NO_DEFAULT):
             # TODO: allow setting 'kind' explicitly.
@@ -196,17 +212,19 @@ class Task(object):
             # bool; that results in a nonsensical Argument which gives the
             # parser grief in a few ways.
             kind = type(default)
-            if not (opts['optional'] and kind is bool):
-                opts['kind'] = kind
-            opts['default'] = default
+            if not (opts["optional"] and kind is bool):
+                opts["kind"] = kind
+            opts["default"] = default
         # Help
         if name in self.help:
-            opts['help'] = self.help[name]
+            opts["help"] = self.help[name]
         return opts
 
     def get_arguments(self):
         """
         Return a list of Argument objects representing this task's signature.
+
+        .. versionadded:: 1.0
         """
         # Core argspec
         arg_names, spec_dict = self.argspec(self.body)
@@ -283,37 +301,40 @@ def task(*args, **kwargs):
     If any non-keyword arguments are given, they are taken as the value of the
     ``pre`` kwarg for convenience's sake. (It is an error to give both
     ``*args`` and ``pre`` at the same time.)
+
+    .. versionadded:: 1.0
     """
     # @task -- no options were (probably) given.
     if len(args) == 1 and callable(args[0]) and not isinstance(args[0], Task):
         return Task(args[0], **kwargs)
     # @task(pre, tasks, here)
     if args:
-        if 'pre' in kwargs:
+        if "pre" in kwargs:
             raise TypeError(
                 "May not give *args and 'pre' kwarg simultaneously!"
             )
-        kwargs['pre'] = args
+        kwargs["pre"] = args
     # @task(options)
     # TODO: pull in centrally defined defaults here (see Task)
     # TODO: clean up all of the values which are iterables, some are tuple and
     # some are None->list, ugh
-    name = kwargs.pop('name', None)
-    aliases = kwargs.pop('aliases', ())
-    positional = kwargs.pop('positional', None)
-    optional = tuple(kwargs.pop('optional', ()))
-    iterable = kwargs.pop('iterable', None)
-    incrementable = kwargs.pop('incrementable', None)
-    default = kwargs.pop('default', False)
-    auto_shortflags = kwargs.pop('auto_shortflags', True)
-    help = kwargs.pop('help', {})
-    pre = kwargs.pop('pre', [])
-    post = kwargs.pop('post', [])
-    autoprint = kwargs.pop('autoprint', False)
+    name = kwargs.pop("name", None)
+    aliases = kwargs.pop("aliases", ())
+    positional = kwargs.pop("positional", None)
+    optional = tuple(kwargs.pop("optional", ()))
+    iterable = kwargs.pop("iterable", None)
+    incrementable = kwargs.pop("incrementable", None)
+    default = kwargs.pop("default", False)
+    auto_shortflags = kwargs.pop("auto_shortflags", True)
+    help = kwargs.pop("help", {})
+    pre = kwargs.pop("pre", [])
+    post = kwargs.pop("post", [])
+    autoprint = kwargs.pop("autoprint", False)
     # Handle unknown kwargs
     if kwargs:
         kwarg = (" unknown kwargs {!r}".format(kwargs)) if kwargs else ""
         raise TypeError("@task was called with" + kwarg)
+
     def inner(obj):
         obj = Task(
             obj,
@@ -331,6 +352,7 @@ def task(*args, **kwargs):
             autoprint=autoprint,
         )
         return obj
+
     return inner
 
 
@@ -341,14 +363,11 @@ class Call(object):
     Similar to `~functools.partial` with some added functionality (such as the
     delegation to the inner task, and optional tracking of the name it's being
     called by.)
+
+    .. versionadded:: 1.0
     """
-    def __init__(
-        self,
-        task,
-        called_as=None,
-        args=None,
-        kwargs=None,
-    ):
+
+    def __init__(self, task, called_as=None, args=None, kwargs=None):
         """
         Create a new `.Call` object.
 
@@ -381,8 +400,12 @@ class Call(object):
         aka = ""
         if self.called_as is not None and self.called_as != self.task.name:
             aka = " (called as: {!r})".format(self.called_as)
-        return "<Call {!r}{}, args: {!r}, kwargs: {!r}>".format(
-            self.task.name, aka, self.args, self.kwargs
+        return "<{} {!r}{}, args: {!r}, kwargs: {!r}>".format(
+            self.__class__.__name__,
+            self.task.name,
+            aka,
+            self.args,
+            self.kwargs,
         )
 
     def __eq__(self, other):
@@ -398,6 +421,8 @@ class Call(object):
     def make_context(self, config):
         """
         Generate a `.Context` appropriate for this call, with given config.
+
+        .. versionadded:: 1.0
         """
         return Context(config=config)
 
@@ -408,6 +433,8 @@ class Call(object):
         Useful when parameterizing task executions.
 
         :param into: A subclass to generate instead of the current class.
+
+        .. versionadded:: 1.0
         """
         return (into if into is not None else self.__class__)(
             task=self.task,
@@ -430,22 +457,24 @@ def call(task, *args, **kwargs):
     `.call`), and one that toggles a boolean flag::
 
         @task
-        def setup(ctx, clean=False):
+        def setup(c, clean=False):
             if clean:
-                ctx.run("rm -rf target")
+                c.run("rm -rf target")
             # ... setup things here ...
-            ctx.run("tar czvf target.tgz target")
+            c.run("tar czvf target.tgz target")
 
         @task(pre=[setup])
-        def build(ctx):
-            ctx.run("build, accounting for leftover files...")
+        def build(c):
+            c.run("build, accounting for leftover files...")
 
         @task(pre=[call(setup, clean=True)])
-        def clean_build(ctx):
-            ctx.run("build, assuming clean slate...")
+        def clean_build(c):
+            c.run("build, assuming clean slate...")
 
     Please see the constructor docs for `.Call` for details - this function's
     ``args`` and ``kwargs`` map directly to the same arguments as in that
     method.
+
+    .. versionadded:: 1.0
     """
     return Call(task=task, args=args, kwargs=kwargs)
